==> libvoikko_3.0.orig.tar.gz: libvoikko-3.0/src/voikko_deprecated.h <==
/* Libvoikko: Finnish spellchecker and hyphenator library
 * Copyright (C) 2006 - 2010 Harri Pitkänen <hatapitk@iki.fi>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *********************************************************************************/

/**
 * This file contains the deprecated public API of libvoikko. The
 * API is still supported although some options no longer have any
 * effect. If you are developing an application that does not need
 * to work with older versions of libvoikko it is recommended to
 * avoid using any of the symbols or macros defined here.
 *
 * You can test that your program is not using any of deprecated API
 * by compiling it with -DVOIKKO_NO_DEPRECATED_API. If the program
 * compiles, you are fine. Do not set this as default compiler option
 * though, since your application may fail to build again after an
 * otherwise backwards compatible upgrade of libvoikko.
 *
 * Everything here will be removed permanently when an API incompatible
 * version of libvoikko is released.
 *
 * NOTICE ABOUT THREAD SAFETY:
 * 
 * It is unsafe to call voikko_init, voikko_init_with_path and
 * voikko_terminate from multiple threads. If you need to do that, all
 * calls to these three functions should be protected with a single mutex.
 * Rather than use this deprecated API please switch to the new API where
 * this particular thread safety issue does not exist.
 */

/**
 * This is an integer option constant. The option no longer has any effect
 * and similar functionality is not provided by the new API. No applications
 * are known to have ever used this.
 */
#define VOIKKO_INTERSECT_COMPOUND_LEVEL 5

/**
 * This is an string option constant. The option no longer has any effect
 * and similar functionality is not provided by the new API. The values for
 * this option were never documented and the option was declared deprecated
 * for a long time before actual implementation was removed.
 */
#define VOIKKO_OPT_ENCODING 2

/**
 * See the notice about thread safety at the top of this file.
 * @param langcode the language code. The following values can be used:
 *        - "", "default" or "fi_FI": Use the default dictionary. The default
 *          dictionary can be assumed to be present in a complete installation of
 *          libvoikko.
 *        - any other string: Use the specified dictionary variant. Usually there
 *          is at least the "standard" variant, but this is not guaranteed. If the
 *          specified dictionary does not exist, an error message is returned.
 *        - NULL: Reserved for future use. Currently leads to undefined behavior.
 * For info on other parameters see documentation for voikkoInit and
 * VOIKKO_SPELLER_CACHE_SIZE.
 */
const char * voikko_init(int * handle, const char * langcode, int cache_size);

/**
 * See the notice about thread safety at the top of this file.
 * @param langcode the language code. The following values can be used:
 *        - "", "default" or "fi_FI": Use the default dictionary. The default
 *          dictionary can be assumed to be present in a complete installation of
 *          libvoikko.
 *        - any other string: Use the specified dictionary variant. Usually there
 *          is at least the "standard" variant, but this is not guaranteed. If the
 *          specified dictionary does not exist, an error message is returned.
 *        - NULL: Reserved for future use. Currently leads to undefined behavior.
 * For info on other parameters see documentation for voikkoInit and
 * VOIKKO_SPELLER_CACHE_SIZE.
 */
const char * voikko_init_with_path(int * handle, const char * langcode,
                                   int cache_size, const char * path);

/**
 * See the notice about thread safety at the top of this file.
 * See voikkoTerminate
 */
int voikko_terminate(int handle);

/**
 * See voikkoSetBooleanOption
 */
int voikko_set_bool_option(int handle, int option, int value);

/**
 * See voikkoSetIntegerOption
 */
int voikko_set_int_option(int handle, int option, int value);

/**
 * Sets a string option. Only used for deprecated VOIKKO_OPT_ENCODING, therefore
 * no replacement has been provided yet.
 * @param handle voikko instance
 * @param option option name
 * @param value option value
 * @return true if option was succesfully set, otherwise false
 */
int voikko_set_string_option(int handle, int option, const char * value);

/**
 * See voikkoSpellCstr
 */
int voikko_spell_cstr(int handle, const char * word);

/**
 * See voikkoSpellUcs4
 */
int voikko_spell_ucs4(int handle, const wchar_t * word);

/**
 * See voikkoSuggestCstr
 */
char ** voikko_suggest_cstr(int handle, const char * word);

/**
 * See voikkoSuggestUcs4
 */
wchar_t ** voikko_suggest_ucs4(int handle, const wchar_t * word);

/**
 * See voikkoHyphenateCstr
 */
char * voikko_hyphenate_cstr(int handle, const char * word);

/**
 * See voikkoHyphenateUcs4
 */
char * voikko_hyphenate_ucs4(int handle, const wchar_t * word);

/**
 * See voikkoFreeCstrArray
 */
void voikko_free_suggest_cstr(char ** suggest_result);

/**
 * See voikkoFreeCstr
 */
void voikko_free_hyphenate(char * hyphenate_result);

/**
 * See voikkoNextTokenUcs4
 */
enum voikko_token_type voikko_next_token_ucs4(int handle, const wchar_t * text,
                       size_t textlen, size_t * tokenlen);

/**
 * See voikkoNextTokenCstr
 */
enum voikko_token_type voikko_next_token_cstr(int handle, const char * text,
                       size_t textlen, size_t * tokenlen);

/**
 * See voikkoNextSentenceStartUcs4
 */
enum voikko_sentence_type voikko_next_sentence_start_ucs4(int handle,
                          const wchar_t * text, size_t textlen, size_t * sentencelen);

/**
 * See voikkoNextSentenceStartCstr
 */
enum voikko_sentence_type voikko_next_sentence_start_cstr(int handle,
                          const char * text, size_t textlen, size_t * sentencelen);

/**
 * See voikkoNextGrammarErrorUcs4
 */
voikko_grammar_error voikko_next_grammar_error_ucs4(int handle, const wchar_t * text,
                     size_t textlen, size_t startpos, int skiperrors);

/**
 * See voikkoNextGrammarErrorCstr
 */
voikko_grammar_error voikko_next_grammar_error_cstr(int handle, const char * text,
                     size_t textlen, size_t startpos, int skiperrors);

/**
 * See voikkoAnalyzeWordUcs4
 */
struct voikko_mor_analysis ** voikko_analyze_word_ucs4(
                              int handle, const wchar_t * word);

/**
 * See voikkoAnalyzeWordCstr
 */
struct voikko_mor_analysis ** voikko_analyze_word_cstr(
                              int handle, const char * word);

==> libvoikko_3.3.orig.tar.gz: libvoikko-3.3/src/voikko_deprecated.h <==
/* Libvoikko: Finnish spellchecker and hyphenator library
 * Copyright (C) 2006 - 2010 Harri Pitkänen <hatapitk@iki.fi>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *********************************************************************************/

/**
 * This file contains the deprecated public API of libvoikko. The
 * API is still supported although some options no longer have any
 * effect. If you are developing an application that does not need
 * to work with older versions of libvoikko it is recommended to
 * avoid using any of the symbols or macros defined here.
 *
 * You can test that your program is not using any of deprecated API
 * by compiling it with -DVOIKKO_NO_DEPRECATED_API. If the program
 * compiles, you are fine. Do not set this as default compiler option
 * though, since your application may fail to build again after an
 * otherwise backwards compatible upgrade of libvoikko.
 *
 * Everything here will be removed permanently when an API incompatible
 * version of libvoikko is released.
 *
 * NOTICE ABOUT THREAD SAFETY:
 * 
 * It is unsafe to call voikko_init, voikko_init_with_path and
 * voikko_terminate from multiple threads. If you need to do that, all
 * calls to these three functions should be protected with a single mutex.
 * Rather than use this deprecated API please switch to the new API where
 * this particular thread safety issue does not exist.
 */

/**
 * This is an integer option constant. The option no longer has any effect
 * and similar functionality is not provided by the new API. No applications
 * are known to have ever used this.
 */
#define VOIKKO_INTERSECT_COMPOUND_LEVEL 5

/**
 * This is an string option constant. The option no longer has any effect
 * and similar functionality is not provided by the new API. The values for
 * this option were never documented and the option was declared deprecated
 * for a long time before actual implementation was removed.
 */
#define VOIKKO_OPT_ENCODING 2

/**
 * Maximum number of analyses for a word. Not strictly enforced anymore.
 * Backends should still limit the number of analyses if necessary to
 * avoid combinatorial explosion.
 */
#define LIBVOIKKO_MAX_ANALYSIS_COUNT 31

/**
 * See the notice about thread safety at the top of this file.
 * @param langcode the language code. The following values can be used:
 *        - "", "default" or "fi_FI": Use the default dictionary. The default
 *          dictionary can be assumed to be present in a complete installation of
 *          libvoikko.
 *        - any other string: Use the specified dictionary variant. Usually there
 *          is at least the "standard" variant, but this is not guaranteed. If the
 *          specified dictionary does not exist, an error message is returned.
 *        - NULL: Reserved for future use. Currently leads to undefined behavior.
 * For info on other parameters see documentation for voikkoInit and
 * VOIKKO_SPELLER_CACHE_SIZE.
 */
const char * voikko_init(int * handle, const char * langcode, int cache_size);

/**
 * See the notice about thread safety at the top of this file.
 * @param langcode the language code. The following values can be used:
 *        - "", "default" or "fi_FI": Use the default dictionary. The default
 *          dictionary can be assumed to be present in a complete installation of
 *          libvoikko.
 *        - any other string: Use the specified dictionary variant. Usually there
 *          is at least the "standard" variant, but this is not guaranteed. If the
 *          specified dictionary does not exist, an error message is returned.
 *        - NULL: Reserved for future use. Currently leads to undefined behavior.
 * For info on other parameters see documentation for voikkoInit and
 * VOIKKO_SPELLER_CACHE_SIZE.
 */
const char * voikko_init_with_path(int * handle, const char * langcode,
                                   int cache_size, const char * path);

/**
 * See the notice about thread safety at the top of this file.
 * See voikkoTerminate
 */
int voikko_terminate(int handle);

/**
 * See voikkoSetBooleanOption
 */
int voikko_set_bool_option(int handle, int option, int value);

/**
 * See voikkoSetIntegerOption
 */
int voikko_set_int_option(int handle, int option, int value);

/**
 * Sets a string option. Only used for deprecated VOIKKO_OPT_ENCODING, therefore
 * no replacement has been provided yet.
 * @param handle voikko instance
 * @param option option name
 * @param value option value
 * @return true if option was succesfully set, otherwise false
 */
int voikko_set_string_option(int handle, int option, const char * value);

/**
 * See voikkoSpellCstr
 */
int voikko_spell_cstr(int handle, const char * word);

/**
 * See voikkoSpellUcs4
 */
int voikko_spell_ucs4(int handle, const wchar_t * word);

/**
 * See voikkoSuggestCstr
 */
char ** voikko_suggest_cstr(int handle, const char * word);

/**
 * See voikkoSuggestUcs4
 */
wchar_t ** voikko_suggest_ucs4(int handle, const wchar_t * word);

/**
 * See voikkoHyphenateCstr
 */
char * voikko_hyphenate_cstr(int handle, const char * word);

/**
 * See voikkoHyphenateUcs4
 */
char * voikko_hyphenate_ucs4(int handle, const wchar_t * word);

/**
 * See voikkoFreeCstrArray
 */
void voikko_free_suggest_cstr(char ** suggest_result);

/**
 * See voikkoFreeCstr
 */
void voikko_free_hyphenate(char * hyphenate_result);

/**
 * See voikkoNextTokenUcs4
 */
enum voikko_token_type voikko_next_token_ucs4(int handle, const wchar_t * text,
                       size_t textlen, size_t * tokenlen);

/**
 * See voikkoNextTokenCstr
 */
enum voikko_token_type voikko_next_token_cstr(int handle, const char * text,
                       size_t textlen, size_t * tokenlen);

/**
 * See voikkoNextSentenceStartUcs4
 */
enum voikko_sentence_type voikko_next_sentence_start_ucs4(int handle,
                          const wchar_t * text, size_t textlen, size_t * sentencelen);

/**
 * See voikkoNextSentenceStartCstr
 */
enum voikko_sentence_type voikko_next_sentence_start_cstr(int handle,
                          const char * text, size_t textlen, size_t * sentencelen);

/**
 * See voikkoNextGrammarErrorUcs4
 */
voikko_grammar_error voikko_next_grammar_error_ucs4(int handle, const wchar_t * text,
                     size_t textlen, size_t startpos, int skiperrors);

/**
 * See voikkoNextGrammarErrorCstr
 */
voikko_grammar_error voikko_next_grammar_error_cstr(int handle, const char * text,
                     size_t textlen, size_t startpos, int skiperrors);

/**
 * See voikkoAnalyzeWordUcs4
 */
struct voikko_mor_analysis ** voikko_analyze_word_ucs4(
                              int handle, const wchar_t * word);

/**
 * See voikkoAnalyzeWordCstr
 */
struct voikko_mor_analysis ** voikko_analyze_word_cstr(
                              int handle, const char * word);
